<template>
    <Head title="Roles"/>

    <AuthenticatedLayout>
        
        <!-- mensaje informativo -->
        <div class="mb-4 inline-flex w-full overflow-hidden rounded-lg bg-white shadow-md">
            <div class="flex w-12 items-center justify-center bg-blue-500">
                <svg class="h-6 w-6 fill-current text-white" viewBox="0 0 40 40">
                    <path
                        d="M20 3.33331C10.8 3.33331 3.33337 10.8 3.33337 20C3.33337 29.2 10.8 36.6666 20 36.6666C29.2 36.6666 36.6667 29.2 36.6667 20C36.6667 10.8 29.2 3.33331 20 3.33331ZM21.6667 28.3333H18.3334V25H21.6667V28.3333ZM21.6667 21.6666H18.3334V11.6666H21.6667V21.6666Z" />
                </svg>
            </div>
            <div class="-mx-3 px-4 py-2">
                <div class="mx-3">
                    <span class="font-semibold text-blue-500">Roles</span>
                    <p class="text-sm text-gray-600">Roles disponibles</p>
                </div>
            </div>
        </div>

        <!-- Botón para abrir modal de creación -->
        <div class="mb-4 flex justify-start">
            <PrimaryButton @click="openCreateModal">
                <i class="fas fa-plus mr-2"></i> Crear Nuevo Rol
            </PrimaryButton>
        </div>

        <!-- tabla de roles -->
        <div class="inline-block min-w-full overflow-hidden rounded-lg shadow">
            <table class="w-full whitespace-no-wrap">
                <thead>
                    <tr class="border-b bg-gray-50 text-left text-xs font-semibold uppercase tracking-wide text-gray-500">
                        <th class="px-5 py-3">Name</th>
                        <th class="px-5 py-3">Acciones</th>
                    </tr>
                </thead>
                <tbody>
                    <tr v-for="role in roles.data" :key="role.id" class="text-gray-700">
                        <td class="border-b border-gray-200 bg-white px-5 py-5 text-sm">
                            <p class="text-gray-900 whitespace-no-wrap">{{ role.name }}</p>
                        </td>
                        <td class="border-b border-gray-200 bg-white px-5 py-5 text-sm space-x-2">
                            <WarningButton @click="openEditModal(role)">
                                Editar
                            </WarningButton>
                            <DangerButton @click="confirmDelete(role.id, role.name)" class="text-red-600 hover:underline">
                                Eliminar            
                            </DangerButton>
                            <SecondaryButton>
                                <inertia-link :href="route('roles.assignPermissions', role.id)" class="text-blue-600 hover:underline">Asignar Permisos</inertia-link>
                            </SecondaryButton>
                        </td>
                    </tr>
                </tbody>
            </table>

            <div class="flex flex-col items-center border-t bg-white px-5 py-5 xs:flex-row xs:justify-between">
                <pagination :links="roles.links" />
            </div>
        </div>

        <!-- Modal para crear nuevo rol -->
        <Modal :show="showCreateModal" @close="closeModal">
            <div class="p-6">
                <h2 class="text-lg font-medium text-gray-900 mb-4">Crear Nuevo Rol</h2>
                
                <form @submit.prevent="submit">
                    <div class="mb-4">
                        <InputLabel for="name" value="Nombre del Rol" />
                        <TextInput
                            id="name"
                            type="text"
                            class="mt-1 block w-full"
                            v-model="createForm.name"
                            required
                            autofocus
                        />
                        <InputError class="mt-2" :message="createForm.errors.name" />
                    </div>

                    <div class="flex justify-end">
                        <SecondaryButton @click="closeModal" class="mr-2">
                            Cancelar
                        </SecondaryButton>
                        <PrimaryButton :class="{ 'opacity-25': createForm.processing }" :disabled="createForm.processing">
                            Guardar
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </Modal>

        <!-- Modal para editar rol -->
        <Modal :show="showEditModal" @close="closeEditModal">
            <div class="p-6">
                <h2 class="text-lg font-medium text-gray-900 mb-4">Editar Rol</h2>
                
                <form @submit.prevent="updateRole">
                    <div class="mb-4">
                        <InputLabel for="edit-name" value="Nombre del Rol" />
                        <TextInput
                            id="edit-name"
                            type="text"
                            class="mt-1 block w-full"
                            v-model="editForm.name"
                            required
                            autofocus
                        />
                        <InputError class="mt-2" :message="editForm.errors.name" />
                    </div>

                    <div class="flex justify-end">
                        <SecondaryButton @click="closeEditModal" class="mr-2">
                            Cancelar
                        </SecondaryButton>
                        <PrimaryButton :class="{ 'opacity-25': editForm.processing }" :disabled="editForm.processing">
                            Actualizar
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </Modal>
    </AuthenticatedLayout>
</template>

<script setup>
import DangerButton from '@/Components/DangerButton.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import WarningButton from '@/Components/WarningButton.vue';
import SecondaryButton from '@/Components/SecondaryButton.vue';
import Modal from '@/Components/Modal.vue';
import { ref } from 'vue';
import Swal from 'sweetalert2';
import AuthenticatedLayout from '@/Layouts/AuthenticatedLayout.vue'
import Pagination from '@/Components/Pagination.vue'
import { Head, useForm, router } from '@inertiajs/vue3'

const props = defineProps({
    roles: Object
})

// Estados de los modales
const showCreateModal = ref(false);
const showEditModal = ref(false);
const currentRole = ref(null);

// Formulario para creación
const createForm = useForm({
    name: '',
});

// Formulario para edición
const editForm = useForm({
    name: '',
});

// Abrir modal de creación
const openCreateModal = () => {
    showCreateModal.value = true;
};

// Abrir modal de edición
const openEditModal = (role) => {
    currentRole.value = role;
    editForm.name = role.name;
    showEditModal.value = true;
};

// Cerrar modales
const closeModal = () => {
    showCreateModal.value = false;
    createForm.reset();
    createForm.clearErrors();
};

const closeEditModal = () => {
    showEditModal.value = false;
    editForm.reset();
    editForm.clearErrors();
};

// Enviar formulario de creación
const submit = () => {
    createForm.post(route('roles.store'), {
        preserveScroll: true,
        onSuccess: () => {
            closeModal();
            Swal.fire({
                title: '¡Éxito!',
                text: 'El rol ha sido creado correctamente.',
                icon: 'success',
                confirmButtonText: 'Aceptar'
            });
        },
        onError: () => {
            Swal.fire({
                title: 'Error',
                text: 'Hubo un problema al crear el rol.',
                icon: 'error',
                confirmButtonText: 'Aceptar'
            });
        }
    });
};

// Actualizar rol
const updateRole = () => {
    editForm.put(route('roles.update', currentRole.value.id), {
        preserveScroll: true,
        onSuccess: () => {
            closeEditModal();
            Swal.fire({
                title: '¡Éxito!',
                text: 'El rol ha sido actualizado correctamente.',
                icon: 'success',
                confirmButtonText: 'Aceptar'
            });
        },
        onError: () => {
            Swal.fire({
                title: 'Error',
                text: 'Hubo un problema al actualizar el rol.',
                icon: 'error',
                confirmButtonText: 'Aceptar'
            });
        }
    });
};

// Confirmar eliminación con SweetAlert2
const confirmDelete = (id, name) => {
    Swal.fire({
        title: '¿Estás seguro?',
        text: `Estás a punto de eliminar el rol "${name}". Esta acción no se puede deshacer.`,
        icon: 'warning',
        showCancelButton: true,
        confirmButtonColor: '#d33',
        cancelButtonColor: '#3085d6',
        confirmButtonText: 'Sí, eliminar',
        cancelButtonText: 'Cancelar'
    }).then((result) => {
        if (result.isConfirmed) {
            router.delete(route('roles.destroy', id), {
                preserveScroll: true,
                onSuccess: () => {
                    Swal.fire(
                        '¡Eliminado!',
                        'El rol ha sido eliminado correctamente.',
                        'success'
                    );
                },
                onError: () => {
                    Swal.fire(
                        'Error',
                        'Hubo un problema al eliminar el rol.',
                        'error'
                    );
                }
            });
        }
    });
};
</script>